@@ -1,11 +1,12 @@
 from fabricks.context import BRONZE, DBUTILS, GOLD, SECRET_SCOPE, SILVER, SPARK, init_spark_session
-from fabricks.core.jobs.base._types import Bronzes, Golds, Silvers
+from fabricks.context.runtime import pprint_runtime
+from fabricks.core.jobs.base._types import Bronzes, Golds, Silvers, Steps
 
 # step
 BRONZES = Bronzes
 SILVERS = Silvers
 GOLDS = Golds
-STEPS = BRONZES + SILVERS + GOLDS
+STEPS = Steps
 
 
 __all__ = [
@@ -17,6 +18,7 @@ __all__ = [
     "Golds",
     "GOLDS",
     "init_spark_session",
+    "pprint_runtime",
     "SECRET_SCOPE",
     "SILVER",
     "Silvers",
