@@ -3,11 +3,14 @@ from fabricks.context.runtime import (
     CATALOG,
     CONF_RUNTIME,
     FABRICKS_STORAGE,
+    FABRICKS_STORAGE_CREDENTIAL,
     GOLD,
-    IS_LIVE,
-    IS_TEST,
+    IS_JOB_CONFIG_FROM_YAML,
+    IS_TYPE_WIDENING,
+    IS_UNITY_CATALOG,
+    LOGLEVEL,
+    PATH_CONFIG,
     PATH_EXTENDERS,
-    PATH_LIBRARIES,
     PATH_PARSERS,
     PATH_REQUIREMENTS,
     PATH_RUNTIME,
@@ -21,21 +24,24 @@ from fabricks.context.runtime import (
     STEPS,
     VARIABLES,
 )
-from fabricks.context.spark_session import DBUTILS, SPARK, get_spark_session, init_spark_session
+from fabricks.context.spark_session import DBUTILS, SPARK, build_spark_session, init_spark_session
 
 __all__ = [
     "BRONZE",
+    "build_spark_session",
     "CATALOG",
     "CONF_RUNTIME",
     "DBUTILS",
+    "FABRICKS_STORAGE_CREDENTIAL",
     "FABRICKS_STORAGE",
-    "get_spark_session",
     "GOLD",
     "init_spark_session",
-    "IS_LIVE",
-    "IS_TEST",
+    "IS_JOB_CONFIG_FROM_YAML",
+    "IS_TYPE_WIDENING",
+    "IS_UNITY_CATALOG",
+    "LOGLEVEL",
+    "PATH_CONFIG",
     "PATH_EXTENDERS",
-    "PATH_LIBRARIES",
     "PATH_PARSERS",
     "PATH_REQUIREMENTS",
     "PATH_RUNTIME",
