@@ -1,4 +1,5 @@
 from fabricks.core.deploy.tables import deploy_tables
+from fabricks.core.deploy.udfs import deploy_udfs
 from fabricks.core.deploy.views import deploy_views
 
 
@@ -10,3 +11,7 @@ class deploy:
     @staticmethod
     def views():
         deploy_views()
+
+    @staticmethod
+    def udfs():
+        deploy_udfs()
