@@ -1,5 +1,4 @@
-import sys
-from importlib.util import spec_from_file_location
+from importlib.util import module_from_spec, spec_from_file_location
 from typing import Optional
 
 from fabricks.context import PATH_PARSERS
@@ -9,15 +8,17 @@ from fabricks.core.parsers.base import PARSERS, BaseParser
 
 def get_parser(name: str, parser_options: Optional[ParserOptions] = None) -> BaseParser:
     if name not in ["json", "parquet", "avro", "csv", "tsv", "delta", "table"]:
-        sys.path.append(PATH_PARSERS.string)
-
-        path = PATH_PARSERS.join(name).append(".py")
+        path = PATH_PARSERS.joinpath(name).append(".py")
         assert path.exists(), f"parser not found ({path})"
+
         spec = spec_from_file_location(name, path.string)
         assert spec, f"parser not found ({path})"
-        spec.loader.load_module()  # type: ignore
+        assert spec.loader is not None
 
+        mod = module_from_spec(spec)
+        spec.loader.exec_module(mod)
         parser = PARSERS[name](parser_options)
+
     else:
         parser = BaseParser(parser_options, name)
 
