@@ -6,5 +6,5 @@ from fabricks.core.steps.base import BaseStep
 
 def get_step(step: Union[TStep, str]) -> BaseStep:
     assert step in Steps, f"{step} not found"
-    _step = BaseStep(step=step)
-    return _step
+    base_step = BaseStep(step=step)
+    return base_step
