@@ -1,10 +1,10 @@
 from fabricks.context import PATH_VIEWS, SPARK
-from fabricks.context.log import Logger
+from fabricks.context.log import DEFAULT_LOGGER
 from fabricks.utils.path import Path
 from fabricks.utils.sqlglot import fix as fix_sql
 
 
-def _create_or_replace_view(path: Path):
+def create_or_replace_view_internal(path: Path):
     sql = path.get_sql()
     file_name = path.get_file_name().split(".")[0]
     sql = f"""
@@ -13,22 +13,22 @@ def _create_or_replace_view(path: Path):
     {sql}
     """
     sql = fix_sql(sql)
-    Logger.debug(f"schedule - %sql\n---\n{sql}\n---")
+    DEFAULT_LOGGER.debug(f"schedule - %sql\n---\n{sql}\n---")
 
     SPARK.sql(sql)
 
 
 def create_or_replace_view(name: str):
-    p = PATH_VIEWS.join(f"{name}.sql")
+    p = PATH_VIEWS.joinpath(f"{name}.sql")
     try:
-        _create_or_replace_view(p)
+        create_or_replace_view_internal(p)
     except Exception:
-        Logger.warning(f"schedule - {name} not created nor replace")
+        DEFAULT_LOGGER.warning(f"schedule - {name} not created nor replace")
 
 
 def create_or_replace_views():
     for p in PATH_VIEWS.walk(file_format="sql", convert=True):
         try:
-            _create_or_replace_view(p)
+            create_or_replace_view_internal(p)
         except Exception:
-            Logger.warning(f"schedule - {p.get_file_name()} not created nor replace")
+            DEFAULT_LOGGER.warning(f"schedule - {p.get_file_name()} not created nor replace")
