@@ -1,33 +1,32 @@
 import re
-from typing import List, Optional, Union, overload
+from typing import List, Optional, Sequence, Union, overload
 
 from delta import DeltaTable
 from pyspark.errors.exceptions.base import AnalysisException
 from pyspark.sql import DataFrame, SparkSession
-from pyspark.sql.functions import expr, max
+from pyspark.sql.functions import max
 from pyspark.sql.types import StructType
-from typing_extensions import deprecated
 
 from fabricks.context import SPARK
-from fabricks.context.log import Logger
-from fabricks.metastore.relational import Relational
+from fabricks.context.log import DEFAULT_LOGGER
+from fabricks.metastore._types import AddedColumn, ChangedColumn, DroppedColumn, SchemaDiff
+from fabricks.metastore.dbobject import DbObject
 from fabricks.utils.path import Path
 from fabricks.utils.sqlglot import fix
 
 
-class Table(Relational):
+class Table(DbObject):
     @classmethod
     def from_step_topic_item(cls, step: str, topic: str, item: str, spark: Optional[SparkSession] = SPARK):
         return cls(step, topic, item, spark=spark)
 
     @property
-    @deprecated("use delta_path instead")
     def deltapath(self) -> Path:
-        return self.database.delta_path.join("/".join(self.levels))
+        return self.database.delta_path.joinpath("/".join(self.levels))
 
     @property
     def delta_path(self) -> Path:
-        return self.database.delta_path.join("/".join(self.levels))
+        return self.database.delta_path.joinpath("/".join(self.levels))
 
     @property
     def deltatable(self) -> DeltaTable:
@@ -39,26 +38,59 @@ class Table(Relational):
 
     @property
     def dataframe(self) -> DataFrame:
+        assert self.is_registered, f"{self} not registered"
+
         return self.spark.sql(f"select * from {self}")
 
     @property
     def columns(self) -> List[str]:
+        assert self.is_registered, f"{self} not registered"
+
         return self.dataframe.columns
 
     @property
     def rows(self) -> int:
+        assert self.is_registered, f"{self} not registered"
+
         return self.spark.sql(f"select count(*) from {self}").collect()[0][0]
 
     @property
     def last_version(self) -> int:
+        assert self.is_registered, f"{self} not registered"
+
         df = self.describe_history()
         version = df.select(max("version")).collect()[0][0]
         return version
 
+    @property
+    def identity_enabled(self) -> bool:
+        assert self.is_registered, f"{self} not registered"
+        return self.get_property("delta.feature.identityColumns") == "supported"
+
+    @property
+    def type_widening_enabled(self) -> bool:
+        assert self.is_registered, f"{self} not registered"
+        return self.get_property("delta.enableTypeWidening") == "true"
+
+    @property
+    def liquid_clustering_enabled(self) -> bool:
+        assert self.is_registered, f"{self} not registered"
+        return self.get_property("delta.feature.clustering") == "supported"
+
+    @property
+    def auto_liquid_clustering_enabled(self) -> bool:
+        assert self.is_registered, f"{self} not registered"
+        return self.get_property("delta.clusterByAuto") == "true"
+
+    @property
+    def vorder_enabled(self) -> bool:
+        assert self.is_registered, f"{self} not registered"
+        return self.get_property("delta.parquet.vorder.enabled") == "true"
+
     def drop(self):
         super().drop()
         if self.delta_path.exists():
-            Logger.debug("delete delta folder", extra={"job": self})
+            DEFAULT_LOGGER.debug("delete delta folder", extra={"job": self})
             self.delta_path.rm()
 
     @overload
@@ -120,7 +152,7 @@ class Table(Relational):
         cluster_by: Optional[Union[List[str], str]] = None,
         properties: Optional[dict[str, str]] = None,
     ):
-        Logger.info("create table", extra={"job": self})
+        DEFAULT_LOGGER.info("create table", extra={"job": self})
         if not df:
             assert schema is not None
             df = self.spark.createDataFrame([], schema)
@@ -141,11 +173,15 @@ class Table(Relational):
         ddl_tblproperties = "-- not tblproperties"
 
         if liquid_clustering:
-            assert cluster_by
-            if isinstance(cluster_by, str):
-                cluster_by = [cluster_by]
-            cluster_by = [f"`{c}`" for c in cluster_by]
-            ddl_cluster_by = "cluster by (" + ", ".join(cluster_by) + ")"
+            if cluster_by:
+                if isinstance(cluster_by, str):
+                    cluster_by = [cluster_by]
+                cluster_by = [f"`{c}`" for c in cluster_by]
+                ddl_cluster_by = "cluster by (" + ", ".join(cluster_by) + ")"
+
+            else:
+                ddl_cluster_by = "cluster by auto"
+
         if partitioning:
             assert partition_by
             if isinstance(partition_by, str):
@@ -158,17 +194,20 @@ class Table(Relational):
 
         if not properties:
             special_char = False
+
             for c in df.columns:
                 match = re.search(r"[^a-zA-Z0-9_]", c)
                 if match:
                     special_char = True
                     break
+
             if special_char:
                 properties = {
                     "delta.columnMapping.mode": "name",
                     "delta.minReaderVersion": "2",
                     "delta.minWriterVersion": "5",
                 }
+
         if properties:
             ddl_tblproperties = (
                 "tblproperties (" + ",".join(f"'{key}' = '{value}'" for key, value in properties.items()) + ")"
@@ -189,113 +228,172 @@ class Table(Relational):
             sql = fix(sql)
         except Exception:
             pass
-        Logger.debug("ddl", extra={"job": self, "sql": sql})
+
+        DEFAULT_LOGGER.debug("ddl", extra={"job": self, "sql": sql})
         self.spark.sql(sql)
 
+    @property
     def is_deltatable(self) -> bool:
         return DeltaTable.isDeltaTable(self.spark, str(self.delta_path))
 
+    @property
     def column_mapping_enabled(self) -> bool:
+        assert self.is_registered, f"{self} not registered"
+
         return self.get_property("delta.columnMapping.mode") == "name"
 
     def exists(self) -> bool:
-        return self.is_deltatable() and self.registered()
+        return self.is_deltatable and self.is_registered
 
     def register(self):
-        Logger.debug("register table", extra={"job": self})
+        DEFAULT_LOGGER.debug("register table", extra={"job": self})
         self.spark.sql(f"create table if not exists {self.qualified_name} using delta location '{self.delta_path}'")
 
     def restore_to_version(self, version: int):
-        Logger.info(f"restore table to version {version}", extra={"job": self})
+        assert self.is_registered, f"{self} not registered"
+
+        DEFAULT_LOGGER.info(f"restore table to version {version}", extra={"job": self})
         self.spark.sql(f"restore table {self.qualified_name} to version as of {version}")
 
     def truncate(self):
-        Logger.warning("truncate table", extra={"job": self})
+        assert self.is_registered, f"{self} not registered"
+
+        DEFAULT_LOGGER.warning("truncate table", extra={"job": self})
         self.create_restore_point()
         self.spark.sql(f"truncate table {self.qualified_name}")
 
-    def schema_drifted(self, df: DataFrame) -> bool:
-        return not self._check_schema_drift(df).isEmpty()
+    def schema_drifted(self, df: DataFrame, exclude_columns_with_prefix: Optional[str] = None) -> bool:
+        assert self.is_registered, f"{self} not registered"
 
-    def _check_schema_drift(self, df: DataFrame) -> DataFrame:
-        Logger.debug("check schema drift", extra={"job": self})
+        diffs = self.get_schema_differences(df)
+        return len(diffs) > 0
 
-        new_df = self.spark.createDataFrame(df.dtypes, ["new_name", "new_type"])  # type: ignore
-        new_df = new_df.filter(~new_df.new_name.startswith("__"))
+    def get_schema_differences(self, df: DataFrame) -> Sequence[SchemaDiff]:
+        assert self.is_registered, f"{self} not registered"
 
-        old_df = self.spark.createDataFrame(self.dataframe.dtypes, ["old_name", "old_type"])  # type: ignore
-        old_df = old_df.filter(~old_df.old_name.startswith("__"))
+        df1 = self.dataframe
+        if self.identity_enabled:
+            if "__identity" in df1.columns:
+                df1 = df1.drop("__identity")
 
-        cond = [new_df["new_name"] == old_df["old_name"]]
-        df_diff = (
-            new_df.join(old_df, on=cond, how="outer")
-            .where(
-                """
-                coalesce(old_name, -1) <> coalesce(new_name, -1) 
-                or 
-                coalesce(old_type, -1) <> coalesce(new_type, -1)
-                """
-            )
-            .withColumn(
-                "operation",
-                expr("if(new_name is null, 'drop', if(old_name is null, 'add', 'update'))"),
-            )
-            .withColumn("column", expr("coalesce(new_name, old_name)"))
-        )
-        return df_diff
+        all_columns = set(df1.columns).union(set(df.columns))
 
-    def _fix_schema(self, df: DataFrame, overwrite: bool = False):
-        drift_df = self._check_schema_drift(df)
+        df1_dict = {name: dtype for name, dtype in df1.dtypes}
+        df2_dict = {name: dtype for name, dtype in df.dtypes}
+
+        diffs: list[SchemaDiff] = []
+
+        for c in all_columns:
+            old_datatype = df1_dict.get(c)
+            new_datatype = df2_dict.get(c)
+
+            if old_datatype is None and new_datatype is not None:
+                diffs.append(AddedColumn(new_column=c, new_data_type=new_datatype))
+
+            elif old_datatype is not None and new_datatype is None:
+                diffs.append(DroppedColumn(column=c, data_type=old_datatype))
+
+            elif old_datatype != new_datatype:
+                assert old_datatype is not None
+                assert new_datatype is not None
+                diffs.append(
+                    ChangedColumn(
+                        column=c,
+                        data_type=old_datatype,
+                        new_data_type=new_datatype,
+                    )
+                )
+
+        if diffs:
+            DEFAULT_LOGGER.debug("difference(s) with delta table", extra={"job": self, "df": df})
+
+        return diffs
+
+    def update_schema(self, df: DataFrame, widen_types: bool = False):
+        assert self.is_registered, f"{self} not registered"
+        if not self.column_mapping_enabled:
+            self.enable_column_mapping()
+
+        diffs = self.get_schema_differences(df)
+        if widen_types:
+            diffs = [d for d in diffs if d.type_widening_compatible]
+            msg = "update schema (type widening only)"
+        else:
+            diffs = [d for d in diffs if d.status in ("added", "changed")]
+            msg = "update schema"
+
+        if diffs:
+            DEFAULT_LOGGER.info(msg, extra={"job": self, "df": diffs})
+
+            for row in diffs:
+                if row.status == "changed":
+                    data_type = f"{row.data_type} -> {row.new_data_type}"
+                else:
+                    data_type = f"{row.new_data_type}"
+
+                DEFAULT_LOGGER.debug(
+                    f"{row.status.replace('ed', 'ing')} {row.column} ({data_type})",
+                    extra={"job": self},
+                )
+
+                try:
+                    # https://docs.databricks.com/aws/en/delta/type-widening#widen-types-with-automatic-schema-evolution
+                    # The type change is not one of byte, short, int, or long to decimal or double.
+                    # These type changes can only be applied manually using ALTER TABLE to avoid accidental promotion of integers to decimals.
+                    if row.data_type in ["byte", "short", "int", "long"] and row.new_data_type in [
+                        "decimal",
+                        "double",
+                    ]:
+                        self.change_column(row.column, row.new_data_type)
 
-        if not drift_df.isEmpty():
-            Logger.info("update table", extra={"job": self})
-            todo_df = drift_df.where("operation in ('add', 'update')")
-            if not todo_df.isEmpty():
-                for row in todo_df.collect():
-                    if row.operation == "add":
-                        Logger.debug(f"add column {row.column}", extra={"job": self})
                     else:
-                        Logger.debug(
-                            f"update column {row.column} ({row.old_type} -> {row.new_type})",
-                            extra={"job": self},
-                        )
-
-                    try:
-                        col_df = df.select(row.column).where("1 == 2")
+                        update_df = df.select(row.column).where("1 == 2")
                         (
                             self.deltatable.alias("dt")
-                            .merge(col_df.alias("df"), "1 == 2")
+                            .merge(update_df.alias("df"), "1 == 2")
+                            .withSchemaEvolution()  # type: ignore
+                            .whenMatchedUpdateAll()
                             .whenNotMatchedInsertAll()
                             .execute()
                         )
-                    except Exception:
-                        pass
-
-            if overwrite:
-                drift_df = self._check_schema_drift(df)
-                Logger.warning("overwrite table", extra={"job": self})
-                for row in drift_df.collect():
-                    if row.operation == "add":
-                        self.add_column(row.column, row.new_type)
-                    elif row.operation == "drop":
-                        self.drop_column(row.column)
-                    elif row.operation == "update":
-                        try:
-                            self.change_column(row.column, row.new_type)
-                        except AnalysisException:
-                            self.drop_column(row.column)
-                            self.add_column(row.column, row.new_type)
-                    else:
-                        raise ValueError(f"{row.operation} not allowed")
-
-    def update_schema(self, df: DataFrame):
-        self._fix_schema(df, overwrite=False)
+                except Exception:
+                    pass
 
     def overwrite_schema(self, df: DataFrame):
-        self._fix_schema(df, overwrite=True)
+        assert self.is_registered, f"{self} not registered"
+        if not self.column_mapping_enabled:
+            self.enable_column_mapping()
+
+        diffs = self.get_schema_differences(df)
+
+        if diffs:
+            self.update_schema(df)
+
+        diffs = self.get_schema_differences(df)
+        if diffs:
+            DEFAULT_LOGGER.warning("overwrite schema", extra={"job": self, "df": diffs})
+
+            for row in diffs:
+                if row.status == "added":
+                    assert row.new_data_type is not None, "new_data_type must be defined for added columns"
+                    self.add_column(row.column, row.new_data_type)
+
+                elif row.status == "dropped":
+                    self.drop_column(row.column)
+
+                elif row.status == "changed":
+                    assert row.new_data_type is not None, "new_data_type must be defined for changed columns"
+
+                    try:
+                        self.change_column(row.column, row.new_data_type)
+                    except AnalysisException:
+                        self.drop_column(row.column)
+                        self.add_column(row.column, row.new_data_type)
 
     def vacuum(self, retention_days: int = 7):
-        Logger.debug(f"vacuum table (removing files older than {retention_days} days)", extra={"job": self})
+        assert self.is_registered, f"{self} not registered"
+
+        DEFAULT_LOGGER.debug(f"vacuum table (removing files older than {retention_days} days)", extra={"job": self})
         self.spark.sql("SET self.spark.databricks.delta.retentionDurationCheck.enabled = False")
         try:
             self.create_restore_point()
@@ -306,57 +404,72 @@ class Table(Relational):
             pass
         self.spark.sql("SET self.spark.databricks.delta.retentionDurationCheck.enabled = True")
 
-    def optimize(
-        self,
-        columns: Optional[Union[str, List[str]]] = None,
-        vorder: Optional[bool] = False,
-    ):
-        Logger.info("optimize", extra={"job": self})
+    def optimize(self, columns: Optional[Union[str, List[str]]] = None):
+        assert self.is_registered, f"{self} not registered"
 
-        zorder_by = columns is not None
-        if zorder_by:
+        DEFAULT_LOGGER.info("optimize", extra={"job": self})
+
+        if self.liquid_clustering_enabled:
+            self.spark.sql(f"optimize {self.qualified_name}")
+
+        elif self.auto_liquid_clustering_enabled:
+            self.spark.sql(f"optimize {self.qualified_name}")
+
+        elif columns is None:
+            if self.vorder_enabled:
+                DEFAULT_LOGGER.debug("vorder", extra={"job": self})
+                self.spark.sql(f"optimize {self.qualified_name} vorder")
+            else:
+                self.spark.sql(f"optimize {self.qualified_name}")
+
+        else:
             if isinstance(columns, str):
                 columns = [columns]
             columns = [f"`{c}`" for c in columns]
             cols = ", ".join(columns)
 
-            if vorder:
-                Logger.debug(f"zorder by {cols} vorder", extra={"job": self})
+            if self.vorder_enabled:
+                DEFAULT_LOGGER.debug(f"zorder by {cols} vorder", extra={"job": self})
                 self.spark.sql(f"optimize {self.qualified_name} zorder by ({cols}) vorder")
+
             else:
-                Logger.debug(f"zorder by {cols}", extra={"job": self})
+                DEFAULT_LOGGER.debug(f"zorder by {cols}", extra={"job": self})
                 self.spark.sql(f"optimize {self.qualified_name} zorder by ({cols})")
 
-        elif vorder:
-            Logger.debug("vorder", extra={"job": self})
-            self.spark.sql(f"optimize {self.qualified_name} vorder")
-
-        else:
-            Logger.debug("optimize", extra={"job": self})
-            self.spark.sql(f"optimize {self.qualified_name}")
-
     def analyze(self):
-        Logger.debug("analyze", extra={"job": self})
+        assert self.is_registered, f"{self} not registered"
+
+        DEFAULT_LOGGER.debug("analyze", extra={"job": self})
         self.compute_statistics()
         self.compute_delta_statistics()
 
     def compute_statistics(self):
-        Logger.debug("compute statistics", extra={"job": self})
+        assert self.is_registered, f"{self} not registered"
+
+        DEFAULT_LOGGER.debug("compute statistics", extra={"job": self})
         cols = [
             f"`{name}`"
             for name, dtype in self.dataframe.dtypes
-            if not dtype.startswith("struct") and not dtype.startswith("array") and name not in ["__metadata"]
+            if not dtype.startswith("struct")
+            and not dtype.startswith("array")
+            and not dtype.startswith("variant")
+            and not dtype.startswith("map")
+            and name not in ["__metadata"]
         ]
         cols = ", ".join(sorted(cols))
-        self.spark.sql(f"analyze table delta.`{self.delta_path}` compute statistics for columns {cols}")
+        self.spark.sql(f"analyze table {self.qualified_name} compute statistics for columns {cols}")
 
     def compute_delta_statistics(self):
-        Logger.debug("compute delta statistics", extra={"job": self})
-        self.spark.sql(f"analyze table delta.`{self.delta_path}` compute delta statistics")
+        assert self.is_registered, f"{self} not registered"
+
+        DEFAULT_LOGGER.debug("compute delta statistics", extra={"job": self})
+        self.spark.sql(f"analyze table {self.qualified_name} compute delta statistics")
 
     def drop_column(self, name: str):
-        assert self.column_mapping_enabled(), "column mapping not enabled"
-        Logger.warning(f"drop column {name}", extra={"job": self})
+        assert self.is_registered, f"{self} not registered"
+        assert self.column_mapping_enabled, "column mapping not enabled"
+
+        DEFAULT_LOGGER.warning(f"drop column {name}", extra={"job": self})
         self.spark.sql(
             f"""
             alter table {self.qualified_name}
@@ -365,8 +478,10 @@ class Table(Relational):
         )
 
     def change_column(self, name: str, type: str):
-        assert self.column_mapping_enabled(), "column mapping not enabled"
-        Logger.info(f"change column {name} ({type})", extra={"job": self})
+        assert self.is_registered, f"{self} not registered"
+        assert self.column_mapping_enabled, "column mapping not enabled"
+
+        DEFAULT_LOGGER.info(f"change column {name} ({type})", extra={"job": self})
         self.spark.sql(
             f"""
             alter table {self.qualified_name}
@@ -375,8 +490,10 @@ class Table(Relational):
         )
 
     def rename_column(self, old: str, new: str):
-        assert self.column_mapping_enabled(), "column mapping not enabled"
-        Logger.info(f"rename column {old} -> {new}", extra={"job": self})
+        assert self.is_registered, f"{self} not registered"
+        assert self.column_mapping_enabled, "column mapping not enabled"
+
+        DEFAULT_LOGGER.info(f"rename column {old} -> {new}", extra={"job": self})
         self.spark.sql(
             f"""
             alter table {self.qualified_name}
@@ -384,25 +501,41 @@ class Table(Relational):
             """
         )
 
+    def get_column_data_type(self, name: str) -> str:
+        data_type = self.get_description().where(f"col_name == '{name}'").select("data_type").collect()[0][0]
+        return data_type
+
     def get_details(self) -> DataFrame:
+        assert self.is_registered, f"{self} not registered"
+
         return self.spark.sql(f"describe detail {self.qualified_name}")
 
     def get_properties(self) -> DataFrame:
+        assert self.is_registered, f"{self} not registered"
+
         return self.spark.sql(f"show tblproperties {self.qualified_name}")
 
     def get_description(self) -> DataFrame:
+        assert self.is_registered, f"{self} not registered"
+
         return self.spark.sql(f"describe extended {self.qualified_name}")
 
     def get_history(self) -> DataFrame:
+        assert self.is_registered, f"{self} not registered"
+
         df = self.spark.sql(f"describe history {self.qualified_name}")
         return df
 
     def get_last_version(self) -> int:
+        assert self.is_registered, f"{self} not registered"
+
         df = self.get_history()
         version = df.select(max("version")).collect()[0][0]
         return version
 
     def get_property(self, key: str) -> Optional[str]:
+        assert self.is_registered, f"{self} not registered"
+
         try:
             value = self.get_properties().where(f"key == '{key}'").select("value").collect()[0][0]
             return value
@@ -411,11 +544,16 @@ class Table(Relational):
             return None
 
     def enable_change_data_feed(self):
-        Logger.debug("enable change data feed", extra={"job": self})
+        assert self.is_registered, f"{self} not registered"
+
+        DEFAULT_LOGGER.debug("enable change data feed", extra={"job": self})
         self.set_property("delta.enableChangeDataFeed", "true")
 
     def enable_column_mapping(self):
-        Logger.debug("enable column mapping", extra={"job": self})
+        assert self.is_registered, f"{self} not registered"
+
+        DEFAULT_LOGGER.debug("enable column mapping", extra={"job": self})
+
         try:
             self.spark.sql(
                 f"""
@@ -423,8 +561,9 @@ class Table(Relational):
                 set tblproperties ('delta.columnMapping.mode' = 'name')
                 """
             )
+
         except Exception:
-            Logger.debug("update reader and writer version", extra={"job": self})
+            DEFAULT_LOGGER.debug("update reader and writer version", extra={"job": self})
             self.spark.sql(
                 f"""
                 alter table {self.qualified_name} 
@@ -437,7 +576,9 @@ class Table(Relational):
             )
 
     def set_property(self, key: Union[str, int], value: Union[str, int]):
-        Logger.debug(f"set property {key} = {value}", extra={"job": self})
+        assert self.is_registered, f"{self} not registered"
+
+        DEFAULT_LOGGER.debug(f"set property {key} = {value}", extra={"job": self})
         self.spark.sql(
             f"""
             alter table {self.qualified_name}
@@ -446,7 +587,9 @@ class Table(Relational):
         )
 
     def add_constraint(self, name: str, expr: str):
-        Logger.debug(f"add constraint ({name} check ({expr}))", extra={"job": self})
+        assert self.is_registered, f"{self} not registered"
+
+        DEFAULT_LOGGER.debug(f"add constraint ({name} check ({expr}))", extra={"job": self})
         self.spark.sql(
             f"""
             alter table {self.qualified_name}
@@ -455,7 +598,9 @@ class Table(Relational):
         )
 
     def add_comment(self, comment: str):
-        Logger.debug(f"add comment '{comment}'", extra={"job": self})
+        assert self.is_registered, f"{self} not registered"
+
+        DEFAULT_LOGGER.debug(f"add comment '{comment}'", extra={"job": self})
         self.spark.sql(
             f"""
             comment on table {self.qualified_name}
@@ -464,8 +609,10 @@ class Table(Relational):
         )
 
     def add_materialized_column(self, name: str, expr: str, type: str):
-        assert self.column_mapping_enabled(), "column mapping not enabled"
-        Logger.info(f"add materialized column ({name} {type})", extra={"job": self})
+        assert self.is_registered, f"{self} not registered"
+        assert self.column_mapping_enabled, "column mapping not enabled"
+
+        DEFAULT_LOGGER.info(f"add materialized column ({name} {type})", extra={"job": self})
         self.spark.sql(
             f""""
             alter table {self.qualified_name}
@@ -474,7 +621,9 @@ class Table(Relational):
         )
 
     def add_column(self, name: str, type: str, after: Optional[str] = None):
-        Logger.info(f"add column {name} ({type})", extra={"job": self})
+        assert self.is_registered, f"{self} not registered"
+
+        DEFAULT_LOGGER.info(f"add column {name} ({type})", extra={"job": self})
         ddl_after = "" if not after else f"after {after}"
         self.spark.sql(
             f"""
@@ -484,12 +633,14 @@ class Table(Relational):
         )
 
     def create_bloomfilter_index(self, columns: Union[str, List[str]]):
+        assert self.is_registered, f"{self} not registered"
+
         if isinstance(columns, str):
             columns = [columns]
         columns = [f"`{c}`" for c in columns]
         cols = ", ".join(columns)
 
-        Logger.info(f"bloomfilter by {cols}", extra={"job": self})
+        DEFAULT_LOGGER.info(f"bloomfilter by {cols}", extra={"job": self})
         self.spark.sql(
             f"""
             create bloomfilter index on table {self.qualified_name}
@@ -498,32 +649,51 @@ class Table(Relational):
         )
 
     def create_restore_point(self):
+        assert self.is_registered, f"{self} not registered"
+
         last_version = self.get_last_version() + 1
         self.set_property("fabricks.last_version", last_version)
 
     def show_properties(self) -> DataFrame:
+        assert self.is_registered, f"{self} not registered"
+
         return self.spark.sql(f"show tblproperties {self.qualified_name}")
 
     def describe_detail(self) -> DataFrame:
+        assert self.is_registered, f"{self} not registered"
+
         return self.spark.sql(f"describe detail {self.qualified_name}")
 
     def describe_extended(self) -> DataFrame:
+        assert self.is_registered, f"{self} not registered"
+
         return self.spark.sql(f"describe extended {self.qualified_name}")
 
     def describe_history(self) -> DataFrame:
+        assert self.is_registered, f"{self} not registered"
+
         df = self.spark.sql(f"describe history {self.qualified_name}")
         return df
 
-    def enable_liquid_clustering(self, columns: Union[str, List[str]]):
-        if isinstance(columns, str):
-            columns = [columns]
-        columns = [f"`{c}`" for c in columns]
-        cols = ", ".join(columns)
-        Logger.info(f"cluster by {cols}", extra={"job": self})
+    def enable_liquid_clustering(self, columns: Optional[Union[str, List[str]]] = None, auto: Optional[bool] = False):
+        assert self.is_registered, f"{self} not registered"
 
-        self.spark.sql(
-            f"""
-            alter table {self.qualified_name}
-            cluster by ({cols})
-            """
-        )
+        if auto:
+            DEFAULT_LOGGER.info("cluster by auto", extra={"job": self})
+            self.spark.sql(f"alter table {self.qualified_name} cluster by automatic")
+
+        else:
+            assert columns, "at least one clustering column must be specified"
+
+            if isinstance(columns, str):
+                columns = [columns]
+            columns = [f"`{c}`" for c in columns]
+            cols = ", ".join(columns)
+
+            DEFAULT_LOGGER.info(f"cluster by {cols}", extra={"job": self})
+            self.spark.sql(
+                f"""
+                alter table {self.qualified_name}
+                cluster by ({cols})
+                """
+            )
