@@ -3,13 +3,14 @@ from uuid import uuid4
 
 import pandas as pd
 from pyspark.sql import DataFrame, SparkSession
+from pyspark.sql.connect.dataframe import DataFrame as CDataFrame
 
 from fabricks.context import SPARK
-from fabricks.context.log import Logger
-from fabricks.metastore.relational import Relational
+from fabricks.context.log import DEFAULT_LOGGER
+from fabricks.metastore.dbobject import DbObject
 
 
-class View(Relational):
+class View(DbObject):
     @staticmethod
     def create_or_replace(
         df: Union[DataFrame, pd.DataFrame],
@@ -17,7 +18,11 @@ class View(Relational):
         spark: Optional[SparkSession] = None,
     ) -> str:
         if spark is None:
-            spark = SPARK
+            if isinstance(df, (DataFrame, CDataFrame)):
+                spark = df.sparkSession
+            else:
+                spark = SPARK
+
         assert spark is not None
 
         uuid = str(uuid4().hex)
@@ -35,6 +40,7 @@ def create_or_replace_global_temp_view(name: str, df: DataFrame, uuid: Optional[
         name = f"{name}__{str(uuid4().hex)}"
 
     job = name.split("__")[0]
-    Logger.debug("create global temp view", extra={"job": job})
+    DEFAULT_LOGGER.debug(f"create global temp view {name}", extra={"job": job})
     df.createOrReplaceGlobalTempView(name)
+
     return f"global_temp.{name}"
