@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import List, Optional
 
 from sqlglot import exp, parse_one, transpile
 from sqlglot.dialects.databricks import Databricks
@@ -13,24 +13,15 @@ class Fabricks(Databricks):
 
 
 def fix(sql: str):
-    """
-    Fixes the given SQL query by parsing it using the 'fabricks' dialect,
-    transpiling it, and returning the fixed SQL query.
-
-    Args:
-        sql (str): The SQL query to be fixed.
-
-    Returns:
-        str: The fixed SQL query.
-    """
-    sql = parse_one(sql, dialect="fabricks").sql()
     sql = transpile(
         sql,
+        "fabricks",
         identify=True,
         pretty=True,
         normalize=False,
         normalize_functions="lower",
-        write="fabricks",
+        leading_comma=True,
+        max_text_width=119,
     )[0]
     return sql
 
@@ -46,3 +37,19 @@ def get_global_temp_view(sql: str) -> Optional[str]:
     for t in tables:
         if "global_temp" in str(t):
             return str(t)
+
+
+def parse(sql: str) -> exp.Expression:
+    return parse_one(sql, dialect="fabricks")
+
+
+def get_tables(sql: str, allowed_databases: Optional[List[str]] = None) -> List[str]:
+    tables = set()
+    for table in parse(sql).find_all(exp.Table):
+        if len(table.db) > 0:  # exclude CTEs
+            if allowed_databases:
+                if table.db not in allowed_databases:
+                    continue
+            tables.add(f"{table.db}.{table.name}")
+    tables = list(tables)
+    return tables
