@@ -14,10 +14,10 @@ class Paths:
 
 
 paths: Final[Paths] = Paths(
-    tests=Path(PATH_RUNTIME.pathlib.parent.resolve(), assume_git=True),
-    landing=FABRICKS_STORAGE.join("landing"),
-    raw=FABRICKS_STORAGE.join("raw"),
-    out=FABRICKS_STORAGE.join("out"),
+    tests=Path(PATH_RUNTIME.pathlibpath.parent.resolve(), assume_git=True),
+    landing=FABRICKS_STORAGE.joinpath("landing"),
+    raw=FABRICKS_STORAGE.joinpath("raw"),
+    out=FABRICKS_STORAGE.joinpath("out"),
 )
 
 steps = ["bronze", "silver", "transf", "gold", "semantic"]
