@@ -6,9 +6,9 @@
 from logging import DEBUG
 
 from databricks.sdk.runtime import dbutils, spark
-from pyspark.sql import Row
+from pyspark.sql.types import Row
 
-from fabricks.context.log import Logger
+from fabricks.context.log import DEFAULT_LOGGER
 from fabricks.core import get_job
 from fabricks.utils.helpers import run_in_parallel
 from tests.integration._types import paths
@@ -16,7 +16,7 @@ from tests.integration.utils import landing_to_raw
 
 # COMMAND ----------
 
-Logger.setLevel(DEBUG)
+DEFAULT_LOGGER.setLevel(DEBUG)
 
 # COMMAND ----------
 
